==> vradi-swing-0.0.1-sources.jar: com/jurismarches/vradi/ui/editors/TextEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import jaxx.runtime.DataBindingListener;

public class TextEditor extends com.jurismarches.vradi.ui.editors.VradiEditor {
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1TPW8TQRAdH7GDY0xCopggghTAJVoDrREkMlhgmQ/hCEW4YX23itc63y27c8nRIH4CPwF6GiQ6KkRBTUGD+AsIUdAiZu9snw1G4OIs7bz35u3M21dfIW80nB3wOGY6ClAOBWvt7O3d7Q2Ei9eFcbVUGGpIfzkHnC6UvMm5QTjfbVt6bUSvNcKhCgMRTLHrbVgy+MQXpi8EIpyZZbjG1DqTcj1WkR6rTkzNU33x/Zvz3Hv20gGIFbmzV9n6Fyu7yUIbHOkhrFKnA17zebBPNrQM9slv2Z41fG7MHT4Uj+EpLLahoLgmMYRz/3/lRCPhxwqhXH2guSdveJIwFxEuuOGQDSItzZBrty8MO7B1FkkmEoxhuyLGFK9UIlRAWPA4coQVa5JZ4yw1niHKKb0RBpg43piZizkkMNvlPV9MUaqtjqtD37/HA3EJ4aRVj0fYqZKFL09YpWrLOtzRgl9GWJ/hjAsWuqpoO6dnXNDeWbb3bDG5LuR1RMdku/tnVO5TKQ3Jxm8hsYJJ9Wdl7dPbL2+a42TkqPf6XOhUsGljSodKaJS29XIaiwilX7vNVb0LRSN8ehVJ6jfnGOuMymSO+p1IlmPp7CY3fZLIL35+977y6OMRcJqw5Ifca3KLvwVF7GuaQuh7sbq2nTg6dniUvivWG+0baZIIx6/YvW/1ZODRfK/GNILNOSOY+OgVP/xY67zenh7Dqb/Cs1HkH0JBBr4MRPJERumf+yRKyojIC7OUz8t9zv5XlFK/AJVc8vNwBAAA";
    private static final long serialVersionUID = 1L;
    protected java.lang.String data;
    private javax.swing.JScrollPane $JScrollPane1;
    private javax.swing.JTextArea $JTextArea2;
    private TextEditor $VradiEditor0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource3 = new DataBindingListener(this, "$JTextArea2.text");

    /* begin raw body code */    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public TextEditor() {
        super();
        $initialize();
    }

    public TextEditor(jaxx.runtime.JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("$JTextArea2.text".equals($binding)) {    
            addPropertyChangeListener("data", $DataSource3);
        } else {
            super.applyDataBinding($binding);
            return;
        }
        processDataBinding($binding);
    }

    @Override
    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("$JTextArea2.text".equals($dest)) {
                jaxx.runtime.SwingUtil.setText($JTextArea2, getData());
            } else {
                super.processDataBinding($dest, true);
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("$JTextArea2.text".equals($binding)) {    
            removePropertyChangeListener("data", $DataSource3);
        } else {
            super.removeDataBinding($binding);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.lang.String getData() {
        return data;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setData(java.lang.String newValue) {
        java.lang.String oldValue = this.data;
        this.data = newValue;
        firePropertyChange("data", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- protected acessors methods ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    protected javax.swing.JScrollPane get$JScrollPane1() {
        return $JScrollPane1;
    }

    protected javax.swing.JTextArea get$JTextArea2() {
        return $JTextArea2;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToEditorContent();
        // inline complete setup of $JScrollPane1
        $JScrollPane1.getViewport().add($JTextArea2);
        // init data bindings
        applyDataBinding("$JTextArea2.text");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$VradiEditor0", this);
        createData();
        // inline creation of $JScrollPane1
        $objectMap.put("$JScrollPane1", $JScrollPane1 = new javax.swing.JScrollPane());
        $JScrollPane1.setName("$JScrollPane1");
        // inline creation of $JTextArea2
        $objectMap.put("$JTextArea2", $JTextArea2 = new javax.swing.JTextArea());
        $JTextArea2.setName("$JTextArea2");
        $JTextArea2.setColumns(15);
        $JTextArea2.setLineWrap(true);
        $JTextArea2.setWrapStyleWord(true);
        // inline creation of $VradiEditor0
        removeDataBinding("$Table0.name");
        setName("$VradiEditor0");
        
        $completeSetup();
    }

    protected void addChildrenToEditorContent() {
        if (!allComponentsCreated) {
            return;
        }
        editorContent.add($JScrollPane1, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createData() {
        $objectMap.put("data", data = null);
    }

    @Override
    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new jaxx.runtime.swing.Table());
        editorContent.setName("editorContent");
    }

}

==> vradi-swing-0.0.2-sources.jar: com/jurismarches/vradi/ui/editors/TextEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import jaxx.runtime.DataBindingListener;

public class TextEditor extends com.jurismarches.vradi.ui.editors.VradiEditor {
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1TPW8TQRAdH7GDE0xCopggghQgJdqD2ggSGSyIzIdwhCLcZH23itc63y27c8nRIH4CPwF6GiQ6KkRBTUGD+AsIUdAiZu8cnw2HwMVZ2nnvzduZt6++QtloOD/gScJ0HKIcCra9tbt7rzcQHt4QxtNSYaQh+5UccLow74/PDcLFbtvS3RHdbUZDFYUinGA32jBn8EkgTF8IRDg3zfCMcTvjciNRsT5SHZsqUn3x/Zvz3H/20gFIFLmzV1n/Fyu/yUwbHOkjLFGnA+4GPNwnG1qG++S3Zs+aATfmLh+Kx/AUZttQUVyTGMKF/79yqpHyE4VQ23iouS9v+pIwlxEuedGQDWItzZBrry8MO7B1FksmUoxhOyLBDK9UKlRBmPE5coRFa5JZ4ywzniNqGb0ZhZg6Xp2aizkkMNvhvUBMUDa2O56OguA+D8UVhNNWPRlhJ0oWvjBmVbJGCCtTcOt6SwtuUUuKFnN2ygCtnOUrz3dS6kJZx3RMjrt/puQBlbJ8rP6WDyuYVn/Wlz+9/fKmdRSKEvVeKYROZJqWpXSkhEZpWy9kiYhRBu4drhpdqBoR0INIA79WYKwzKpM56ncq3Yuls1vc9EmiPPv53fv63sdj4LRgLoi43+IWfxuq2Nc0hSjwE3V9M3V04vA4fRetN1o10iQRTl61K1/vydCn+V5LaARrBSMY++hVP/xY7rzenBzDmb/C81GUH0FFhoEMRfo6RsEvfA3zyojYj/KAF0W+ZP/rSqlfecSwQmsEAAA=";
    private static final long serialVersionUID = 1L;
    protected java.lang.String data;
    protected javax.swing.JTextArea editor;
    private javax.swing.JScrollPane $JScrollPane1;
    private TextEditor $VradiEditor0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource2 = new DataBindingListener(this, "editor.text");

    /* begin raw body code */    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public TextEditor() {
        super();
        $initialize();
    }

    public TextEditor(jaxx.runtime.JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("editor.text".equals($binding)) {    
            addPropertyChangeListener("data", $DataSource2);
        } else {
            super.applyDataBinding($binding);
            return;
        }
        processDataBinding($binding);
    }

    @Override
    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("editor.text".equals($dest)) {
                jaxx.runtime.SwingUtil.setText(editor, getData());
            } else {
                super.processDataBinding($dest, true);
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("editor.text".equals($binding)) {    
            removePropertyChangeListener("data", $DataSource2);
        } else {
            super.removeDataBinding($binding);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.lang.String getData() {
        return data;
    }

    public javax.swing.JTextArea getEditor() {
        return editor;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setData(java.lang.String newValue) {
        java.lang.String oldValue = this.data;
        this.data = newValue;
        firePropertyChange("data", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- protected acessors methods ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    protected javax.swing.JScrollPane get$JScrollPane1() {
        return $JScrollPane1;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToEditorContent();
        // inline complete setup of $JScrollPane1
        $JScrollPane1.getViewport().add(editor);
        // init data bindings
        applyDataBinding("editor.text");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$VradiEditor0", this);
        createData();
        // inline creation of $JScrollPane1
        $objectMap.put("$JScrollPane1", $JScrollPane1 = new javax.swing.JScrollPane());
        $JScrollPane1.setName("$JScrollPane1");
        createEditor();
        // inline creation of $VradiEditor0
        removeDataBinding("$Table0.name");
        setName("$VradiEditor0");
        
        $completeSetup();
    }

    protected void addChildrenToEditorContent() {
        if (!allComponentsCreated) {
            return;
        }
        editorContent.add($JScrollPane1, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createData() {
        $objectMap.put("data", data = null);
    }

    protected void createEditor() {
        $objectMap.put("editor", editor = new javax.swing.JTextArea());
        editor.setName("editor");
        editor.setColumns(15);
        editor.setLineWrap(true);
        editor.setWrapStyleWord(true);
    }

    @Override
    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new jaxx.runtime.swing.Table());
        editorContent.setName("editorContent");
    }

}
